# jintonic

A package of tools for composition in just intonation with Python.

David B. Doty's technical definition of just intonation :

_Just Intonation is any system of tuning in which all of the intervals can be
represented by whole-number frequency ratios, with a strongly implied preference
for the simplest ratios compatible with a given musical purpose._

You can find a more lyrical definition in the first chapter of his primer, which
is [available online](http://www.dbdoty.com/Words/Primer_2.1.html).

I strongly recommend his book :
[Just Intonation Primer](http://www.dbdoty.com/Words/Primer1.html).

## Installing

```
pip install jintonic
```

## Documentation

[Full documentation is available here.](https://inegm.github.io/jintonic/)